==> haskell-hls-explicit-record-fields-plugin-2.0.0.0-42-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hls-explicit-record-fields-plugin.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hls-explicit-record-fields-plugin
version:              2.0.0.0
visibility:           public
id:
    hls-explicit-record-fields-plugin-2.0.0.0-5a5Q48MCyaEGHGFlMOwXVi

key:
    hls-explicit-record-fields-plugin-2.0.0.0-5a5Q48MCyaEGHGFlMOwXVi

license:              BSD-3-Clause
maintainer:           berk.ozkutuk@tweag.io
author:               Berk Ozkutuk
synopsis:             Explicit record fields plugin for Haskell Language Server
description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server#readme>

category:             Development
abi:                  11e7e84ed5acfcc7b3483c0bd00b647b
exposed:              True
exposed-modules:      Ide.Plugin.ExplicitFields
import-dirs:
    /usr/lib/ghc-9.4.8/site-local/hls-explicit-record-fields-plugin-2.0.0.0

library-dirs:
    /usr/lib/ghc-9.4.8/site-local/hls-explicit-record-fields-plugin-2.0.0.0

library-dirs-static:
    /usr/lib/ghc-9.4.8/site-local/hls-explicit-record-fields-plugin-2.0.0.0

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hls-explicit-record-fields-plugin
hs-libraries:
    HShls-explicit-record-fields-plugin-2.0.0.0-5a5Q48MCyaEGHGFlMOwXVi

depends:
    base-4.17.2.1 containers-0.6.7 ghc-boot-th-9.4.8
    ghcide-2.0.0.0-Bw55j8ivRdS1lZn7awmkvP
    hls-graph-2.0.0.0-DCuPmB8SSO3BYT2keh0jHr
    hls-plugin-api-2.0.0.0-45nymQkyoUp6CHZYfB0y5r
    lens-5.2.3-2UQe7k3aogFYCJ4tqsIcu lsp-1.6.0.0-AIlM1Pv3sP459C6JGeqr1z
    syb-0.7.2.4-2YD6CDfMmJX8WUaza11ezv text-2.0.2 transformers-0.5.6.2
    unordered-containers-0.2.20-I6MqYi1ZitpKUe3ww5yyKM

haddock-interfaces:
    /usr/share/doc/haskell-hls-explicit-record-fields-plugin/html/hls-explicit-record-fields-plugin.haddock

haddock-html:
    /usr/share/doc/haskell-hls-explicit-record-fields-plugin/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hls-explicit-record-fields-plugin-2.0.0.0-43-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hls-explicit-record-fields-plugin.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hls-explicit-record-fields-plugin
version:              2.0.0.0
visibility:           public
id:
    hls-explicit-record-fields-plugin-2.0.0.0-GHGBLYbSqs4IGWBCuscjvX

key:
    hls-explicit-record-fields-plugin-2.0.0.0-GHGBLYbSqs4IGWBCuscjvX

license:              BSD-3-Clause
maintainer:           berk.ozkutuk@tweag.io
author:               Berk Ozkutuk
synopsis:             Explicit record fields plugin for Haskell Language Server
description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server#readme>

category:             Development
abi:                  f58490fbb20fb360d40c932d70756409
exposed:              True
exposed-modules:      Ide.Plugin.ExplicitFields
import-dirs:
    /usr/lib/ghc-9.4.8/site-local/hls-explicit-record-fields-plugin-2.0.0.0

library-dirs:
    /usr/lib/ghc-9.4.8/site-local/hls-explicit-record-fields-plugin-2.0.0.0

library-dirs-static:
    /usr/lib/ghc-9.4.8/site-local/hls-explicit-record-fields-plugin-2.0.0.0

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hls-explicit-record-fields-plugin
hs-libraries:
    HShls-explicit-record-fields-plugin-2.0.0.0-GHGBLYbSqs4IGWBCuscjvX

depends:
    base-4.17.2.1 containers-0.6.7 ghc-boot-th-9.4.8
    ghcide-2.0.0.0-1gwnwbdcXosF15uYSqqK1D
    hls-graph-2.0.0.0-DCuPmB8SSO3BYT2keh0jHr
    hls-plugin-api-2.0.0.0-45nymQkyoUp6CHZYfB0y5r
    lens-5.2.3-2UQe7k3aogFYCJ4tqsIcu lsp-1.6.0.0-AIlM1Pv3sP459C6JGeqr1z
    syb-0.7.2.4-2YD6CDfMmJX8WUaza11ezv text-2.0.2 transformers-0.5.6.2
    unordered-containers-0.2.20-I6MqYi1ZitpKUe3ww5yyKM

haddock-interfaces:
    /usr/share/doc/haskell-hls-explicit-record-fields-plugin/html/hls-explicit-record-fields-plugin.haddock

haddock-html:
    /usr/share/doc/haskell-hls-explicit-record-fields-plugin/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
